@@ -1,5 +1,6 @@
 #include <glade/glade.h>
 #include <gmpc/plugin.h>
+#include <config.h>
 /* External pointer + function, there internal from gmpc */
 extern GladeXML *pl3_xml;
 int stop_song();
@@ -37,7 +38,7 @@ static void set_enabled() {
 }
 gmpcPlugin plugin = {
 	"Stop Button Add",
-	{0,15.0},
+	{PLUGIN_MAJOR_VERSION,PLUGIN_MINOR_VERSION,PLUGIN_MICRO_VERSION},
 	GMPC_PLUGIN_NO_GUI,
 	0,  	/* plugin id */
 	NULL,   /* path to plugin */
